@@ -365,7 +365,7 @@ translate_compile_error (gint *errcode, const gchar **errmsg)
     case 45:
       /* These errors should not happen as we are using an UTF8-enabled PCRE
        * and we do not check if strings are valid */
-      g_warning (*errmsg);
+      g_warning ("%s", *errmsg);
       *errcode = G_REGEX_ERROR_COMPILE;
       break;
     default:
@@ -794,7 +794,7 @@ g_match_info_fetch (const GMatchInfo *match_info,
  * @start_pos: pointer to location where to store the start position
  * @end_pos: pointer to location where to store the end position
  *
- * Retrieves the position of the @match_num<!-- -->'th capturing 
+ * Retrieves the position in bytes of the @match_num<!-- -->'th capturing 
  * parentheses. 0 is the full text of the match, 1 is the first 
  * paren set, 2 the second, and so on.
  *
@@ -917,7 +917,7 @@ g_match_info_fetch_named (const GMatchInfo *match_info,
  * @start_pos: pointer to location where to store the start position
  * @end_pos: pointer to location where to store the end position
  *
- * Retrieves the position of the capturing parentheses named @name.
+ * Retrieves the position in bytes of the capturing parentheses named @name.
  *
  * If @name is a valid sub pattern name but it didn't match anything 
  * (e.g. sub pattern "X", matching "b" against "(?P&lt;X&gt;a)?b") 
@@ -1055,8 +1055,8 @@ g_regex_unref (GRegex *regex)
 /** 
  * g_regex_new:
  * @pattern: the regular expression
- * @compile_options: compile options for the regular expression
- * @match_options: match options for the regular expression
+ * @compile_options: compile options for the regular expression, or 0 
+ * @match_options: match options for the regular expression, or 0
  * @error: return location for a #GError
  * 
  * Compiles the regular expression to an internal form, and does 
@@ -1096,7 +1096,7 @@ g_regex_new (const gchar         *pattern,
       if (!support)
 	{
 	  msg = N_("PCRE library is compiled without UTF8 support");
-	  g_critical (msg);
+	  g_critical ("%s", msg);
 	  g_set_error_literal (error, G_REGEX_ERROR, G_REGEX_ERROR_COMPILE, gettext (msg));
 	  return NULL;
 	}
@@ -1105,7 +1105,7 @@ g_regex_new (const gchar         *pattern,
       if (!support)
 	{
 	  msg = N_("PCRE library is compiled without UTF8 properties support");
-	  g_critical (msg);
+	  g_critical ("%s", msg);
 	  g_set_error_literal (error, G_REGEX_ERROR, G_REGEX_ERROR_COMPILE, gettext (msg));
 	  return NULL;
 	}
@@ -1273,8 +1273,8 @@ g_regex_get_capture_count (const GRegex *regex)
  * g_regex_match_simple:
  * @pattern: the regular expression
  * @string: the string to scan for matches
- * @compile_options: compile options for the regular expression
- * @match_options: match options
+ * @compile_options: compile options for the regular expression, or 0
+ * @match_options: match options, or 0
  *
  * Scans for a match in @string for @pattern.
  *
@@ -1287,7 +1287,7 @@ g_regex_get_capture_count (const GRegex *regex)
  * once, it's more efficient to compile the pattern once with
  * g_regex_new() and then use g_regex_match().
  *
- * Returns: %TRUE is the string matched, %FALSE otherwise
+ * Returns: %TRUE if the string matched, %FALSE otherwise
  *
  * Since: 2.14
  */
@@ -1351,6 +1351,10 @@ g_regex_match_simple (const gchar        *pattern,
  * }
  * ]|
  *
+ * @string is not copied and is used in #GMatchInfo internally. If 
+ * you use any #GMatchInfo method (except g_match_info_free()) after 
+ * freeing or modifying @string then the behaviour is undefined.
+ *
  * Returns: %TRUE is the string matched, %FALSE otherwise
  *
  * Since: 2.14
@@ -1478,6 +1482,10 @@ g_regex_match_full (const GRegex      *regex,
  * i.e. you must free it regardless if regular expression actually 
  * matched.
  *
+ * @string is not copied and is used in #GMatchInfo internally. If 
+ * you use any #GMatchInfo method (except g_match_info_free()) after 
+ * freeing or modifying @string then the behaviour is undefined.
+ * 
  * Returns: %TRUE is the string matched, %FALSE otherwise
  *
  * Since: 2.14
@@ -1536,6 +1544,10 @@ g_regex_match_all (const GRegex      *regex,
  * i.e. you must free it regardless if regular expression actually 
  * matched.
  *
+ * @string is not copied and is used in #GMatchInfo internally. If 
+ * you use any #GMatchInfo method (except g_match_info_free()) after 
+ * freeing or modifying @string then the behaviour is undefined.
+ *
  * Returns: %TRUE is the string matched, %FALSE otherwise
  *
  * Since: 2.14
@@ -1638,8 +1650,8 @@ g_regex_get_string_number (const GRegex *regex,
  * g_regex_split_simple:
  * @pattern: the regular expression
  * @string: the string to scan for matches
- * @compile_options: compile options for the regular expression
- * @match_options: match options
+ * @compile_options: compile options for the regular expression, or 0
+ * @match_options: match options, or 0
  *
  * Breaks the string on the pattern, and returns an array of 
  * the tokens. If the pattern contains capturing parentheses, 
@@ -1669,7 +1681,7 @@ g_regex_get_string_number (const GRegex *regex,
  * characters. For example splitting "ab c" using as a separator 
  * "\s*", you will get "a", "b" and "c".
  *
- * Returns: a %NULL-terminated gchar ** array. Free it using g_strfreev()
+ * Returns: a %NULL-terminated array of strings. Free it using g_strfreev()
  *
  * Since: 2.14
  **/
@@ -2530,6 +2542,45 @@ g_regex_replace_literal (const GRegex      *regex,
  * string and setting #G_REGEX_MATCH_NOTBOL in the case of a pattern 
  * that begins with any kind of lookbehind assertion, such as "\b".
  *
+ * The following example uses g_regex_replace_eval() to replace multiple
+ * strings at once:
+ * |[
+ * static gboolean 
+ * eval_cb (const GMatchInfo *info,          
+ *          GString          *res,
+ *          gpointer          data)
+ * {
+ *   gchar *match;
+ *   gchar *r;
+ * 
+ *    match = g_match_info_fetch (info, 0);
+ *    r = g_hash_table_lookup ((GHashTable *)data, match);
+ *    g_string_append (res, r);
+ *    g_free (match);
+ * 
+ *    return FALSE;
+ * }
+ * 
+ * /&ast; ... &ast;/
+ * 
+ * GRegex *reg;
+ * GHashTable *h;
+ * gchar *res;
+ *
+ * h = g_hash_table_new (g_str_hash, g_str_equal);
+ * 
+ * g_hash_table_insert (h, "1", "ONE");
+ * g_hash_table_insert (h, "2", "TWO");
+ * g_hash_table_insert (h, "3", "THREE");
+ * g_hash_table_insert (h, "4", "FOUR");
+ * 
+ * reg = g_regex_new ("1|2|3|4", 0, 0, NULL);
+ * res = g_regex_replace_eval (reg, text, -1, 0, 0, eval_cb, h, NULL);
+ * g_hash_table_destroy (h);
+ *
+ * /&ast; ... &ast;/
+ * ]|
+ *
  * Returns: a newly allocated string containing the replacements
  *
  * Since: 2.14
